@@ -1,27 +1,27 @@
 GeomVline <- proto(Geom, {
-	new <- function(., aesthetics=aes(), data=NULL, intercept=1, ...) {
+	new <- function(., mapping=aes(), data=NULL, intercept=1, ...) {
 		if (missing(data)) {
 			data <- data.frame(intercept = intercept)
 		}
-		aesthetics <- defaults(aesthetics, aes(intercept=intercept))
-		layer(aesthetics=aesthetics, data=data, geom = ., geom_params = list(...))
+		mapping <- defaults(mapping, aes(intercept=intercept))
+		layer(mapping=mapping, data=data, geom = ., geom_params = list(...))
 	}
 
 	draw <- function(., data, scales, coordinates, ...) {
 		yrange <- coordinates$frange()$y
 
-		gTree(children = do.call(gList, lapply(1:nrow(data), function(i) {
+		ggname(.$my_name(), gTree(children = do.call(gList, lapply(1:nrow(data), function(i) {
 			row <- data[c(i, i), ]
 			row$y <- yrange
 			row$x <- row$intercept
 
 			GeomPath$draw(row, scales, coordinates)
-		})))
+		}))))
 	}
 
 	objname <- "vline"
 	desc <- "Line, vertical"
-	icon <- function(.) linesGrob(c(0, 1), c(0.5, 0.5))
+	icon <- function(.) linesGrob(c(0.5, 0.5), c(0, 1))
 	
 	default_stat <- function(.) StatIdentity
 	default_aes <- function(.) c(GeomPath$default_aes(), aes(intercept=0))
