@@ -1,5 +1,4 @@
 ScaleShape <- proto(ScaleDiscrete, expr={
-	objname <- "shape"
 	common <- NULL
 	.input <- .output <- "shape"
 	solid <- TRUE
@@ -19,10 +18,23 @@ ScaleShape <- proto(ScaleDiscrete, expr={
 	max_levels <- function(.) 6
 	guide_legend_geom <- function(.) GeomPoint
 	
+	# Documetation -----------------------------------------------
+	objname <- "shape"
+	description <- "Scale for shapes, aka glyphs"
+	icon <- function(.) {
+		gTree(children=gList(
+			circleGrob(0.7, 0.7, r=0.1),
+			segmentsGrob(0.2, 0.3, 0.4, 0.3),
+			segmentsGrob(0.3, 0.2, 0.3, 0.4),
+			polygonGrob(c(0.2, 0.2, 0.4, 0.4), c(0.8, 0.6, 0.6, 0.8)),
+			polygonGrob(c(0.6, 0.7, 0.8), c(0.2, 0.4, 0.2))
+		))
+	}
+	
 	examples <- function(.) {
 		dsmall <- diamonds[sample(nrow(diamonds), 100), ]
 		
-		(d <- qplot(carat, price, data=diamonds, shape=cut))
+		(d <- qplot(carat, price, data=dsmall, shape=cut))
 		d + scale_shape(solid = TRUE) # the default
 		d + scale_shape(solid = FALSE)
 		d + scale_shape(name="Cut of diamond")
